# Copyright (C) 2007  Romel Sandoval
#
# This file is part of Plogger.
#
# Plogger is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Plogger is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gtkmvc
from gtkmvc import view
import os.path

GLADE_NAME = "task.glade"
GLADE_PATH = "./gui" 

GLADE = os.path.join(GLADE_PATH, GLADE_NAME)

class Model(gtkmvc.model.Model):

    __properties__ = {
        "message_index" : -1 # initial value
        }

    def __init__(self):
        gtkmvc.model.Model.__init__(self)

        self.messages= ('Initial message',
                        'Another message', 
                        'A third message...',
                        'Model changed again')
        return

    def get_message(self, index): return self.messages[index]

    def set_next_message(self):
        self.message_index = (self.message_index + 1) % len(self.messages)
        

class View(gtkmvc.view.View):

    def __init__(self, controller):
        gtkmvc.view.View.__init__(self, controller, GLADE)
        
    def clean(self):
        self['date_entry'].set_text('')

class Controller(gtkmvc.controller.Controller):

    def __init__(self, model):
        gtkmvc.controller.Controller.__init__(self, model)
        self.plog_controller = None

    def registerView(self, view):
        gtkmvc.controller.Controller.registerView(self, view)
        
        # Connects the exiting signal:
        view['task_dlg'].connect('delete_event', self.hide)
        view['calendar_dlg'].connect('delete_event', self.hide)
        
    def on_calendar_btn_clicked(self, widget):
        self.view['calendar_dlg'].show()
        
    def on_task_cancel_btn_clicked(self, button):
        self.plog_controller.view['statusbar'].push(4, 'Task edit cancelled')
        self.view['task_dlg'].hide()
    
    def hide(self, widget, event, data=None):
        widget.hide()
        return True
        
class Agent(object):

    def __init__(self, plog_controller):
        model = Model()
        self.controller  = Controller(model)
        self.view  = View(self.controller)
        self.controller.plog_controller = plog_controller
    
    def show(self):
        self.view.clean()
        self.view['task_dlg'].show()
        
